==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/WOLABORSCHEDULINGWOACTIVITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour WOLABORSCHEDULINGWOACTIVITYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WOLABORSCHEDULINGWOACTIVITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WOLABORSCHEDULINGWOACTIVITYID_Type", propOrder = {
    "activityid",
    "dbsessionid"
})
public class WOLABORSCHEDULINGWOACTIVITYID_Type {

    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "DBSESSIONID", required = true)
    protected QUANTITY dbsessionid;

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété dbsessionid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Définit la valeur de la propriété dbsessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/WOLABORSCHEDULINGWOACTIVITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for WOLABORSCHEDULINGWOACTIVITYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WOLABORSCHEDULINGWOACTIVITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WOLABORSCHEDULINGWOACTIVITYID_Type", propOrder = {
    "activityid",
    "dbsessionid"
})
public class WOLABORSCHEDULINGWOACTIVITYID_Type {

    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "DBSESSIONID", required = true)
    protected QUANTITY dbsessionid;

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the dbsessionid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Sets the value of the dbsessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

}
